@@ -169,7 +169,7 @@ get_client_id (GoaOAuth2Provider *oauth2_provider)
 static const gchar *
 get_client_secret (GoaOAuth2Provider *oauth2_provider)
 {
-  return GOA_GOOGLE_CLIENT_SECRET;
+  return "";
 }
 
 static gboolean
@@ -195,15 +195,13 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
   gchar *ret = NULL;
   gchar *email = NULL;
 
-  /* TODO: cancellable */
-
   proxy = goa_rest_proxy_new ("https://www.googleapis.com/oauth2/v2/userinfo", FALSE);
   call = rest_proxy_new_call (proxy);
   rest_proxy_call_set_method (call, "GET");
   rest_proxy_call_add_param (call, "access_token", access_token);
   rest_proxy_call_add_param (call, "fields", "email");
 
-  if (!rest_proxy_call_sync (call, error))
+  if (!goa_rest_proxy_call_sync (call, cancellable, error))
     goto out;
   if (rest_proxy_call_get_status_code (call) != 200)
     {
